Learn R Programming

fma (version 2.2)

fancy: Sales for a souvenir shop

Description

Monthly sales for a souvenir shop on the wharf at a beach resort town in Queensland, Australia.

Usage

fancy

Arguments

Format

Time series data

Makridakis, Wheelwright and Hyndman (1998) Forecasting: methods and applications, John Wiley & Sons: New York. Exercise 5.8.

Examples

Run this code
seasonplot(fancy)

Run the code above in your browser using DataLab